@@ -142,6 +142,8 @@ class ZNP:
         self._app = None
         self._config = config
 
+        self.version = None
+
         self._response_listeners = defaultdict(list)
         self._sync_request_lock = asyncio.Lock()
 
@@ -153,16 +155,22 @@ class ZNP:
     def _port_path(self) -> str:
         return self._config[conf.CONF_DEVICE][conf.CONF_DEVICE_PATH]
 
-    async def connect(self) -> None:
+    async def connect(self, *, test_port=True) -> None:
         assert self._uart is None
 
-        self._uart = await uart.connect(self._config[conf.CONF_DEVICE], self)
-        LOGGER.debug("Testing connection to %s", self._uart.transport.serial.name)
-
         try:
-            # Make sure that our port works
-            await self.request(c.SYS.Ping.Req())
+            self._uart = await uart.connect(self._config[conf.CONF_DEVICE], self)
+
+            if test_port:
+                LOGGER.debug(
+                    "Testing connection to %s", self._uart.transport.serial.name
+                )
+
+                # Make sure that our port works
+                await self.request(c.SYS.Ping.Req())
+                self.version = await self.request(c.SYS.Version.Req())
         except Exception:
+            self.version = None
             self._uart = None
             raise
 
@@ -309,7 +317,9 @@ class ZNP:
                 response = await response_future
 
         if isinstance(response, c.RPCError.CommandNotRecognized.Rsp):
-            raise CommandNotRecognized(f"Fatal request error: {response}")
+            raise CommandNotRecognized(
+                f"Fatal request error {response} in response to {request}"
+            )
 
         # If the sync response we got is not what we wanted, this is an error
         if not partial_response.matches(response):
@@ -343,8 +353,10 @@ class ZNP:
                 "Extend one of the tables in zigpy_znp.types.nvids."
             )
 
-        if not isinstance(value, bytes):
+        if hasattr(value, "serialize"):
             value = value.serialize()
+        elif not isinstance(value, (bytes, bytearray)):
+            raise TypeError("Only bytes or serializable types can be written to NVRAM")
 
         return await self.request(
             c.SYS.OSALNVWrite.Req(Id=nv_id, Offset=offset, Value=t.ShortBytes(value)),
